Log

Struct Log 

pub struct Log<'a> {
    pub level: LogLevel,
    pub content: LogContent<'a>,
    pub cause: Option<Box<Log<'a>>>,
}
A configured log.

Fields

level: LogLevelcontent: LogContent<'a>cause: Option<Box<Log<'a>>>

Implementations

Source

impl<'a> Log<'a>

pub fn new(level: LogLevel) -> Log<'a>

Builds a new log.

pub fn trace() -> Log<'a>

Builds a new log with a trace level.

pub fn debug() -> Log<'a>

Builds a new log with a debug level.

pub fn info() -> Log<'a>

Builds a new log with an info level.

pub fn warn() -> Log<'a>

Builds a new log with a warn level.

pub fn error() -> Log<'a>

Builds a new log with an error level.

pub fn set_cause<F>(self, builder: F) -> Self
where F: FnOnce(Log<'_>) -> Log<'_>,

Sets the cause of this log.

pub fn add_block(self, block: impl Into<LogBlock<'a>>) -> Self

Adds a new block.

pub fn log_plain_text(&self)

Logs in the console the plain text version of the log.

pub fn log_styled_text(&self)

Logs in the console the styled text version of the log.

pub fn log(&self)

Logs in the console the text version of the log. Whether it is styled or plain text depends on whether the ANSI colors are supported in the executing terminal or not.

pub fn append_plain_to_file(&self, file: &Path) -> Result<()>

Appends the log into the specified file as plain text.

pub fn append_styled_to_file(&self, file: &Path) -> Result<()>

Appends the log into the specified file as styled text.

pub fn to_plain_text(&self) -> String

Returns the log as a plain text.

pub fn to_styled_text(&self) -> String

Returns the log as a styled text.

pub fn to_text(&self) -> String

Returns the log as text. Whether it is styled or plain text depends on whether the ANSI colors are supported in the executing terminal or not.

pub fn make_owned(self) -> Log<'static>

Makes this type owned, i.e. changing the lifetime to 'static.