pub struct Log<'a> {
pub level: LogLevel,
pub content: LogContent<'a>,
pub cause: Option<Box<Log<'a>>>,
}Expand description
A configured log.
Fields
level: LogLevelcontent: LogContent<'a>cause: Option<Box<Log<'a>>>Implementations
Sourceimpl<'a> Log<'a>
impl<'a> Log<'a>
Sourcepub fn log_plain_text(&self)
pub fn log_plain_text(&self)
Logs in the console the plain text version of the log.
Sourcepub fn log_styled_text(&self)
pub fn log_styled_text(&self)
Logs in the console the styled text version of the log.
Sourcepub fn log(&self)
pub fn log(&self)
Logs in the console the text version of the log. Whether it is styled or plain text depends on whether the ANSI colors are supported in the executing terminal or not.
Sourcepub fn append_plain_to_file(&self, file: &Path) -> Result<()>
pub fn append_plain_to_file(&self, file: &Path) -> Result<()>
Appends the log into the specified file as plain text.
Sourcepub fn append_styled_to_file(&self, file: &Path) -> Result<()>
pub fn append_styled_to_file(&self, file: &Path) -> Result<()>
Appends the log into the specified file as styled text.
Sourcepub fn to_plain_text(&self) -> String
pub fn to_plain_text(&self) -> String
Returns the log as a plain text.
Sourcepub fn to_styled_text(&self) -> String
pub fn to_styled_text(&self) -> String
Returns the log as a styled text.
Sourcepub fn to_text(&self) -> String
pub fn to_text(&self) -> String
Returns the log as text. Whether it is styled or plain text depends on whether the ANSI colors are supported in the executing terminal or not.
Sourcepub fn make_owned(self) -> Log<'static>
pub fn make_owned(self) -> Log<'static>
Makes this type owned, i.e. changing the lifetime to 'static.